==> Repetier-Server-Frontend-0.86.2.zip: Repetier-Server-Frontend/wwwsrc/modules/front2/app/temperatures.component.ts <==
/* (C) 2016 Hot-World GmbH & Co. KG <rlittwin@repetier.com>
 All Rights Reserved

 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY
 DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

 It is allowed to use this code to create or use in products connecting to
 Repetier-Server or to use it for own plugins/modules with Repetier-Server.
 This includes free and commercial products.
 Usage for other products is strictly forbidden.
 */

import {Component} from '@angular/core';
import {RSSelect} from "@repetier/front-ui";
import {PrinterAction,PrintersAction,PrinterState,PrintersState} from "@repetier/binding";
import {select} from 'ng2-redux';
import {Observable} from 'rxjs/Observable';
import {ISubscription} from "rxjs/Subscription";

@Component({
    selector: 'rs-temperatures-component',
    template: `
<rs-page>
<side>
    <rs-sideicon title="<?php _('Home') ?>" icon="fa fa-home" link="/"></rs-sideicon>
</side>
<side><rs-sideicon *ifPrinting="true" title="<?php _('Print') ?>" icon="rs rs-print" link="/print-status"></rs-sideicon></side>
<side><rs-sideicon *ifConnected="true" title="<?php _('Params') ?>" icon="rs rs-params" link="/params"></rs-sideicon></side>
<main>
    <h1><?php _('Temperatures') ?></h1>
    <div class="content-h1">
    <div style="display: table;width:100%;height:100%;margin:0;padding:0; " *ngIf="active">
        <div style="display: table-row;height:1px;">
        <div class="margin-leftright margin-bottom">
            <rs-button (hit)="selectExtruder()" class="secondary full">{{cur.name}}: {{p?.currentTemp|fixed:1}} | {{p?.tempSet|fixed:0}}°C <span class="caret"></span> </rs-button>
            </div>
        </div>
        <div style="display: table-row;margin:0;padding:0;">
            <rs-temp-graph [extruder]="cur.id"></rs-temp-graph>
        </div>
    </div>
    </div>
</main>
</rs-page>
    `
})
export class TemperaturesComponent {
    cur: any = {};
    list: any = [];
    p: any = {};
    active: PrinterState = undefined;
    @select('printers') printers$:Observable<PrintersState>;

    private printersSubscription:ISubscription;
    constructor(public select: RSSelect) {
        this.printersSubscription = this.printers$.subscribe((p:PrintersState) => {
            if(p.active) {
                this.active = p.printers[p.active];
                if (!this.active)
                    return;
                if (p.stateTime != 0 && this.list.length == 0 && this.active.config.general)
                    this.updateList();
                if (this.cur.id == -1)
                    this.p = this.active.heatedBed;
                else if (this.cur.id == -2)
                    this.p = this.active.heatedChamber;
                else
                    this.p = this.active.extruders[this.cur.id];
            } else this.active = undefined;
        });
    }

    ngOnDestroy():void {
        this.printersSubscription.unsubscribe();
    }

    updateList() {
        if (!this.active)
            return;
        this.list = [];
        for (let idx in this.active.extruders) {
            this.list.push({id: idx, name: "<?php _('Extruder') ?> " + (parseInt(idx) + 1)});
        }
        if (this.active.config.general.heatedBed)
            this.list.push({id: -1, name: "<?php _('Heated Bed') ?>"});
        if (this.active.config.heatedChamber.installed)
            this.list.push({id: -2, name: "<?php _('Heated Chamber') ?>"});
        if (this.list.length > 0)
            this.cur = this.list[0];
    }

    selectExtruder() {
        this.select.select(this.list, "name", "<?php _('Select Graph') ?>").then((data)=> {
            this.cur = data;
        });
    }
}

==> Repetier-Server-Frontend-0.90.1.zip: Repetier-Server-Frontend/wwwsrc/modules/front2/app/temperatures.component.ts <==
/* (C) 2016-2018 Hot-World GmbH & Co. KG <rlittwin@repetier.com>
 All Rights Reserved

 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY
 DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

 It is allowed to use this code to create or use in products connecting to
 Repetier-Server or to use it for own plugins/modules with Repetier-Server.
 This includes free and commercial products.
 Usage for other products is strictly forbidden.
 */

import {Component} from '@angular/core';
import {RSSelect} from "@repetier/front-ui";
import {PrinterAction,PrintersAction,PrinterState,PrintersState} from "@repetier/binding";
import {select} from 'ng2-redux';
import {Observable} from 'rxjs/Observable';
import {ISubscription} from "rxjs/Subscription";

@Component({
    selector: 'rs-temperatures-component',
    template: `
<rs-page>
<side>
    <rs-sideicon title="<?php _('Home') ?>" icon="fa fa-home" link="/"></rs-sideicon>
</side>
<side><rs-sideicon *ifPrinting="true" title="<?php _('Print') ?>" icon="rs rs-print" link="/print-status"></rs-sideicon></side>
<side><rs-sideicon *ifConnected="true" title="<?php _('Params') ?>" icon="rs rs-params" link="/params"></rs-sideicon></side>
<main>
    <h1><?php _('Temperatures') ?></h1>
    <div class="content-h1">
    <div style="display: table;width:100%;height:100%;margin:0;padding:0; " *ngIf="active">
        <div style="display: table-row;height:1px;">
        <div class="margin-leftright margin-bottom">
            <rs-button (hit)="selectExtruder()" class="secondary full">{{cur.name}}: {{p?.currentTemp|fixed:1}} | {{p?.tempSet|fixed:0}}°C <span class="caret"></span> </rs-button>
            </div>
        </div>
        <div style="display: table-row;margin:0;padding:0;">
            <rs-temp-graph [extruder]="cur.id"></rs-temp-graph>
        </div>
    </div>
    </div>
</main>
</rs-page>
    `
})
export class TemperaturesComponent {
    cur: any = {};
    list: any = [];
    p: any = {};
    active: PrinterState = undefined;
    @select('printers') printers$:Observable<PrintersState>;

    private printersSubscription:ISubscription;
    constructor(public select: RSSelect) {
        this.printersSubscription = this.printers$.subscribe((p:PrintersState) => {
            if(p.active) {
                this.active = p.printers[p.active];
                if (!this.active)
                    return;
                if (p.stateTime != 0 && this.list.length == 0 && this.active.config.general)
                    this.updateList();
                if (this.cur.id == -1)
                    this.p = this.active.heatedBeds[0];
                else if (this.cur.id == -2)
                    this.p = this.active.heatedChambers[0];
                else
                    this.p = this.active.extruders[this.cur.id];
            } else this.active = undefined;
        });
    }

    ngOnDestroy():void {
        this.printersSubscription.unsubscribe();
    }

    updateList() {
        if (!this.active)
            return;
        this.list = [];
        for (let idx in this.active.extruders) {
            this.list.push({id: idx, name: "<?php _('Extruder') ?> " + (parseInt(idx) + 1)});
        }
        if (this.active.config.heatedBeds.length)
            this.list.push({id: 1000, name: "<?php _('Heated Bed') ?>"});
        if (this.active.config.heatedChambers.length)
            this.list.push({id: 2000, name: "<?php _('Heated Chamber') ?>"});
        if (this.list.length > 0)
            this.cur = this.list[0];
    }

    selectExtruder() {
        this.select.select(this.list, "name", "<?php _('Select Graph') ?>").then((data)=> {
            this.cur = data;
        });
    }
}
